@@ -118,6 +118,6 @@ func (d *Document) parseListItem(l List, i int, parentStop stopFn) (int, Node) {
 	return i - start, ListItem{bullet, status, value, nodes}
 }
 
-func (n List) String() string                { return orgWriter.WriteNodesAsString(n) }
-func (n ListItem) String() string            { return orgWriter.WriteNodesAsString(n) }
-func (n DescriptiveListItem) String() string { return orgWriter.WriteNodesAsString(n) }
+func (n List) String() string                { return String(n) }
+func (n ListItem) String() string            { return String(n) }
+func (n DescriptiveListItem) String() string { return String(n) }
